@@ -1,42 +1,43 @@
-import { IResource } from './resource'
-import { V1ObjectMeta } from '@kubernetes/client-node'
-import { listResources } from '../lib/resource-request'
+/* Copyright Contributors to the Open Cluster Management project */
 
-export const DiscoveredClusterApiVersion = 'discovery.open-cluster-management.io/v1'
-export type DiscoveredClusterApiVersionType = 'discovery.open-cluster-management.io/v1'
+import { V1ObjectMeta } from '@kubernetes/client-node/dist/gen/model/v1ObjectMeta'
+import { listResources } from '../lib/resource-request'
+import { IResource, IResourceDefinition } from './resource'
+
+export const DiscoveredClusterApiVersion = 'discovery.open-cluster-management.io/v1alpha1'
+export type DiscoveredClusterApiVersionType = 'discovery.open-cluster-management.io/v1alpha1'
 
 export const DiscoveredClusterKind = 'DiscoveredCluster'
 export type DiscoveredClusterKindType = 'DiscoveredCluster'
 
+export const DiscoveredClusterDefinition: IResourceDefinition = {
+    apiVersion: DiscoveredClusterApiVersion,
+    kind: DiscoveredClusterKind,
+}
+
 export interface DiscoveredCluster extends IResource {
     apiVersion: DiscoveredClusterApiVersionType
     kind: DiscoveredClusterKindType
     metadata: V1ObjectMeta
     spec: {
-        activity_timestamp: string
-        apiUrl?: string
-        cloudProvider: string
-        console: string
-        creation_timestamp?: string
-        healthState: string
         name: string
+        console: string
+        apiUrl: string
+        displayName: string
+        creationTimestamp?: string
+        activityTimestamp: string
         openshiftVersion: string
-        product: string
-        providerConnections?: {
+        cloudProvider: string
+        status: string
+        type: string
+        isManagedCluster: boolean
+        credential?: {
             apiVersion: string
             kind: string
             name: string
             namespace: string
             resourceVersion: string
             uid: string
-        }[]
-        region: string
-        state: string
-        subscription: {
-            creator_id: string
-            managed: boolean
-            status: string
-            support_level?: string
         }
     }
 }
